aboutsummaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorTomohiro Kusumi <[email protected]>2019-06-20 04:27:31 +0900
committerBrian Behlendorf <[email protected]>2019-06-19 12:27:31 -0700
commitfb0be12d7b6db16eabfe8f91da12da7d7854ea9a (patch)
tree63153c91ff8557d6ea99bd157efd09fa2310f651 /lib
parent0b755ec3d5ba531d2662da54fb9ac62627ce2c66 (diff)
Use ZFS_DEV macro instead of literals
The rest of the code/comments use ZFS_DEV, so sync with that. Reviewed-by: Tony Hutter <[email protected]> Reviewed-by: Brian Behlendorf <[email protected]> Reviewed-by: Richard Elling <[email protected]> Signed-off-by: Tomohiro Kusumi <[email protected]> Closes #8912
Diffstat (limited to 'lib')
-rw-r--r--lib/libzfs_core/libzfs_core.c6
-rw-r--r--lib/libzpool/util.c2
2 files changed, 4 insertions, 4 deletions
diff --git a/lib/libzpool/util.c b/lib/libzpool/util.c
index ad05d2239..67bc209ce 100644
--- a/lib/libzpool/util.c
+++ b/lib/libzpool/util.c
@@ -223,7 +223,7 @@ pool_active(void *unused, const char *name, uint64_t guid,
* Use ZFS_IOC_POOL_SYNC to confirm if a pool is active
*/
- fd = open("/dev/zfs", O_RDWR);
+ fd = open(ZFS_DEV, O_RDWR);
if (fd < 0)
return (-1);
diff --git a/lib/libzfs_core/libzfs_core.c b/lib/libzfs_core/libzfs_core.c
index 9e8968879..8ee1dd5e5 100644
--- a/lib/libzfs_core/libzfs_core.c
+++ b/lib/libzfs_core/libzfs_core.c
@@ -52,7 +52,7 @@
*
* - Thin Layer. libzfs_core is a thin layer, marshaling arguments
* to/from the kernel ioctls. There is generally a 1:1 correspondence
* between libzfs_core functions and ioctls to /dev/zfs.
*
* - Clear Atomicity. Because libzfs_core functions are generally 1:1
* with kernel ioctls, and kernel ioctls are general atomic, each
@@ -135,7 +135,7 @@ libzfs_core_init(void)
{
(void) pthread_mutex_lock(&g_lock);
if (g_refcount == 0) {
- g_fd = open("/dev/zfs", O_RDWR);
+ g_fd = open(ZFS_DEV, O_RDWR);
if (g_fd < 0) {
(void) pthread_mutex_unlock(&g_lock);
return (errno);
@@ -499,7 +499,7 @@ lzc_sync(const char *pool_name, nvlist_t *innvl, nvlist_t **outnvl)
* The snapshots must all be in the same pool.
* The value is the name of the hold (string type).
*
* If cleanup_fd is not -1, it must be the result of open("/dev/zfs", O_EXCL).
* In this case, when the cleanup_fd is closed (including on process
* termination), the holds will be released. If the system is shut down
* uncleanly, the holds will be released when the pool is next opened
@@ -52,7 +52,7 @@
* - Thin Layer. libzfs_core is a thin layer, marshaling arguments
* to/from the kernel ioctls. There is generally a 1:1 correspondence
- * between libzfs_core functions and ioctls to /dev/zfs.
+ * between libzfs_core functions and ioctls to ZFS_DEV.
*
* - Clear Atomicity. Because libzfs_core functions are generally 1:1
@@ -499,7 +499,7 @@ lzc_sync(const char *pool_name, nvlist_t *innvl, nvlist_t **outnvl)
* The value is the name of the hold (string type).
*
- * If cleanup_fd is not -1, it must be the result of open("/dev/zfs", O_EXCL).
+ * If cleanup_fd is not -1, it must be the result of open(ZFS_DEV, O_EXCL).
* In this case, when the cleanup_fd is closed (including on process
* termination), the holds will be released. If the system is shut down